@@ -3,7 +3,7 @@ imputeFAMD <- function (X, ncp = 2, method=c("Regularized","EM"),row.w=NULL,coef
   method <- match.arg(method,c("Regularized","regularized","EM","em"),several.ok=T)[1]
   method <- tolower(method)
   type = rep("s",ncol(X))
-  type[!unlist(lapply(X,is.numeric))]="n"
+  type[!sapply(X,is.numeric)]="n"
   res <- imputeMFA(X=X,group=rep(1,ncol(X)),type=type, ncp = ncp, method=method,row.w=row.w,coeff.ridge=coeff.ridge,threshold = threshold,seed = seed,maxiter=maxiter)
   return(res)
 }
